@@ -194,7 +194,9 @@ class FileSystemCommands(unittest.TestCase):
                             return_value='First name: foo\nLast name: bar'):
                 # just hide stdout
                 with mock.patch('sys.stdout'):
-                    khard.main(['new', '-a', 'abook1'])
+                    # hide warning about missing version in vcard
+                    with self.assertLogs(level='WARNING'):
+                        khard.main(['new', '-a', 'abook1'])
         new = len(list(self.abook1.glob('*.vcf')))
         self.assertEqual(new, old + 1)
 
@@ -233,7 +235,7 @@ class MiscCommands(unittest.TestCase):
         with mock.patch('subprocess.Popen') as popen:
             # just hide stdout
             with mock.patch('sys.stdout'):
-                khard.main(["source", "uid1"])
+                khard.main(["edit", "--format=vcard", "uid1"])
         popen.assert_called_once_with(['editor',
                                        'test/fixture/foo.abook/contact1.vcf'])
 
